package com.liferay.test;

import javax.inject.Inject;

import javax.portlet.PortletConfig;

import javax.portlet.RenderResponse;
import javax.portlet.annotations.LocaleString;
import javax.portlet.annotations.PortletConfiguration;
import javax.portlet.annotations.RenderMethod;
import javax.portlet.annotations.Supports;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Enumeration;
import java.util.List;

@PortletConfiguration(
	portletName = "hello_world",
	title = @LocaleString(value = "com.liferay.test.lps106072.portlet"),
	supports = {
		@Supports(mimeType = "text/html", portletModes = {
			"view", "help", "edit"}, windowStates = {
			"normal", "maximized", "minimized"}),
		@Supports(mimeType = "text/xml", portletModes = {
			"view", "help"}, windowStates = {
			"normal"})
	}
)
public class HelloWorldPortlet {

	@Inject
	private PortletConfig _portletConfig;

	@Inject
	private RenderResponse _renderResponse;

	@RenderMethod(portletNames = {"hello_world"})
	public String renderView() {

		StringBuilder sb = new StringBuilder();

		sb.append(getResults("portlet modes", "text/html",
			Arrays.asList("edit", "help", "view"),
			enum2SortedList(_portletConfig.getPortletModes("text/html"))));

		sb.append(getResults("window states", "text/html",
			Arrays.asList("maximized", "minimized", "normal"),
			enum2SortedList(_portletConfig.getWindowStates("text/html"))));

		sb.append(getResults("portlet modes", "text/xml",
			Arrays.asList("help", "view"),
			enum2SortedList(_portletConfig.getPortletModes("text/xml"))));

		sb.append(getResults("window states", "text/xml",
			Arrays.asList("normal"),
			enum2SortedList(_portletConfig.getWindowStates("text/xml"))));

		return sb.toString();
	}

	private List<String> enum2SortedList(Enumeration<?> enumeration) {

		List<String> list = new ArrayList<>();

		while (enumeration.hasMoreElements()) {
			list.add(enumeration.nextElement().toString());
		}

		Collections.sort(list);

		return list;
	}

	private String getResults(
		String type, String mimeType, List<String> expectedList,
		List<String> actualList) {

		if (expectedList.equals(actualList)) {
			return "<p>PASS: " + type + " for \"" + mimeType + "\" are [" +
				   String.join(",", expectedList) + "]";
		}
		else {
			return "<p>FAIL: " + type + " for \"" + mimeType + "\" are [" +
				   String.join(",", actualList) +
				   "] but should be [" + String.join(
				",",
				expectedList) + "]";
		}
	}
}